@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\IMAP;
@@ -96,7 +80,7 @@ class MailboxSync {
 		LoggerInterface $logger,
 		bool $force = false): void {
 		if (!$force && $account->getMailAccount()->getLastMailboxSync() >= ($this->timeFactory->getTime() - 7200)) {
-			$logger->debug("account is up to date, skipping mailbox sync");
+			$logger->debug('account is up to date, skipping mailbox sync');
 			return;
 		}
 
@@ -123,7 +107,7 @@ class MailboxSync {
 				$this->folderMapper->fetchFolderAcls($folders, $client);
 			} catch (Horde_Imap_Client_Exception $e) {
 				throw new ServiceException(
-					sprintf("IMAP error synchronizing account %d: %s", $account->getId(), $e->getMessage()),
+					sprintf('IMAP error synchronizing account %d: %s', $account->getId(), $e->getMessage()),
 					$e->getCode(),
 					$e
 				);
@@ -225,7 +209,7 @@ class MailboxSync {
 		foreach ($namespaces as $namespace) {
 			/** @var Horde_Imap_Client_Data_Namespace $namespace */
 			if ($namespace->type === Horde_Imap_Client::NS_PERSONAL) {
-				return $namespace->name !== "" ? $namespace->name : null;
+				return $namespace->name !== '' ? $namespace->name : null;
 			}
 		}
 		return null;
@@ -278,12 +262,14 @@ class MailboxSync {
 		[$sync, $doNotSync] = array_reduce($mailboxes, function (array $carry, Mailbox $mailbox) use ($personalNamespace): array {
 			/** @var array{0: Mailbox[], 1: Mailbox[]} $carry */
 			[$sync, $doNotSync] = $carry;
-			$inboxName = $personalNamespace === null ? "INBOX" : ($personalNamespace . $mailbox->getDelimiter() . "INBOX");
+			$inboxName = $personalNamespace === null ? 'INBOX' : ($personalNamespace . $mailbox->getDelimiter() . 'INBOX');
 			if ($inboxName === $mailbox->getName() || $mailbox->getSyncInBackground()) {
 				return [
 					array_merge($sync, [$mailbox]),
 					$doNotSync,
 				];
+			} elseif ($mailbox->getSelectable() === false) {
+				return [$sync, $doNotSync];
 			}
 			return [
 				$sync,
@@ -299,9 +285,11 @@ class MailboxSync {
 			return $mailbox->getName();
 		}, $syncStatus));
 		foreach ($syncStatus as $mailbox) {
-			$status = $statuses[$mailbox->getName()];
-			$mailbox->setMessages($status->getTotal());
-			$mailbox->setUnseen($status->getUnread());
+			$status = $statuses[$mailbox->getName()] ?? null;
+			if ($status !== null) {
+				$mailbox->setMessages($status->getTotal());
+				$mailbox->setUnseen($status->getUnread());
+			}
 		}
 		$this->atomic(function () use ($syncStatus) {
 			foreach ($syncStatus as $mailbox) {
